@@ -1,5 +1,4 @@
-/* kpTerm.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -70,7 +69,7 @@ void kpTerm::doUnconnect()
 		   SLOT(keyOut(char)));
 }
 
-bool kpTerm::run(QString cmd, QStringList &r) 
+bool kpTerm::run(const QString &cmd, QStringList &r) 
 {
   setReadOnly(FALSE);
   setFocus();
