@@ -1,5 +1,4 @@
-/* pkgInterface.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -93,7 +92,7 @@ public:
   virtual QStringList verify(packageInfo *p, const QStringList &files);
   // check the installed files in a package
 
-  virtual QStringList FindFile(const QString &name) = 0;
+  virtual QStringList FindFile(const QString &name, bool seachAll=false) = 0;
   // search for packages containg a file
 
   virtual QStringList getChangeLog(packageInfo *p) = 0;
@@ -200,6 +199,9 @@ public:
   bool hasRemote;
   // can access on remote host
 
+  bool hasSearchAll;
+  // can search uninstalled packages for files
+
 public slots:
   virtual void setLocation() = 0;
   virtual void setAvail(LcacheObj *) = 0;
