@@ -1,5 +1,4 @@
-/* pkgOptions.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // This provides the installation options, plus the install and cancel
@@ -57,8 +56,8 @@ public:
   pkgOptions( pkgInterface *pki, QWidget *parent=0, const QString &caption=QString::null);
   ~pkgOptions();
 
-  void setup(QPtrList<packageInfo> *pl, QString type);
-  void setup(packageInfo *p, QString type);
+  void setup(QPtrList<packageInfo> *pl, const QString &type);
+  void setup(packageInfo *p, const QString &type);
   void reset();
 
   virtual QString doPackages(int installFlags, QPtrList<packageInfo> *p,
@@ -122,8 +121,8 @@ protected:
 
   void getKeep();
 
-  void hideEvent(QHideEvent*);
   void showEvent (QShowEvent *);
+  void closeEvent (QCloseEvent * e );
 
   void terminate();
 };
